@@ -6,8 +6,7 @@ use Mouse::Util::TypeConstraints;
 
 use Try::Tiny;
 
-use Elive '1.13';
-
+use Elive::DAO '0.01';
 extends 'Elive::DAO';
 
 use Carp;
@@ -18,13 +17,13 @@ Elive::StandardV2 - Perl bindings for the Elluminate Live Standard Bridge (V2) [
 
 =head1 VERSION
 
-Version 0.01_5
+Version 0.01_6
 
 ** DEVELOPER RELEASE - UNDER CONSTRUCTION **
 
 =cut
 
-our $VERSION = '0.01_5';
+our $VERSION = '0.01_6';
 
 use 5.008003;
 
@@ -155,8 +154,6 @@ Returns the default Elive connection handle.
 
 =cut
 
-__PACKAGE__->mk_classdata('connection');
-
 =head2 update
 
 Abstract method to commit outstanding object updates to the server.
